<?php
/*
Plugin Name: Contributors's Posts
Plugin URI: http://wordpress.org/extend/plugins/contributors-posts/
Description: A plugin to manage posts of contributors with the same account without having to create other users.
Version: 0.7.2.1
Author: Simone "Magicianred" Paolucci
Author URI: http://simone.paolucci.name
License: GPL

Copyright 2013 Magicianred (email: magicianred@gmail.com)
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */



/* CUSTOM TYPE */
function mgr_cp_contributorpost() {
	$labels = array(
		'name'               => _x( 'Contributors Posts', 'post type general name' ),
		'singular_name'      => _x( 'Contributor Post', 'post type singular name' ),
		'add_new'            => _x( 'Add New', 'contributorpost' ),
		'add_new_item'       => __( 'Add New Contributor Post', 'mgr_cp' ),
		'edit_item'          => __( 'Edit Contributor Post', 'mgr_cp' ),
		'new_item'           => __( 'New Contributor Post', 'mgr_cp' ),
		'all_items'          => __( 'All Contributors Posts', 'mgr_cp' ),
		'view_item'          => __( 'View Contributor Post', 'mgr_cp' ),
		'search_items'       => __( 'Search Contributors Posts', 'mgr_cp' ),
		'not_found'          => __( 'No contributors posts found', 'mgr_cp' ),
		'not_found_in_trash' => __( 'No contributors posts found in the Trash', 'mgr_cp' ),
		'parent_item_colon'  => '',
		'menu_name'          => 'Contributors Posts'
	);
	$args = array(
		'labels'        => $labels,
		'description'   => __('Holds our contributors and contributors posts specific data', 'mgr_cp'),
		'public'        => true,
		'menu_position' => 5,
		'supports'      => array( 'title', 'editor', 'custom-fields', 'thumbnail', 'excerpt', 'comments' ),
		'has_archive'   => true,
    	'taxonomies' => array('category', 'post_tag')
	);
	register_post_type( 'contributorpost', $args );
}
add_action( 'init', 'mgr_cp_contributorpost' );


function mgr_cp_updated_messages( $messages ) {
	global $post, $post_ID;
	$messages['contributorpost'] = array(
		0 => '',
		1 => sprintf( __('Contributor Post updated. <a href="%s">View Contributor Post</a>'), esc_url( get_permalink($post_ID) ) ),
		2 => __('Custom field updated.'),
		3 => __('Custom field deleted.'),
		4 => __('Contributor Post updated.'),
		5 => isset($_GET['revision']) ? sprintf( __('Contributor Post restored to revision from %s'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Contributor Post published. <a href="%s">View Contributor Post</a>'), esc_url( get_permalink($post_ID) ) ),
		7 => __('Contributor Post saved.'),
		8 => sprintf( __('Contributor Post submitted. <a target="_blank" href="%s">Preview Contributor Post</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		9 => sprintf( __('Contributor Post scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Contributor Post</a>'), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
		10 => sprintf( __('Contributor Post draft updated. <a target="_blank" href="%s">Preview Contributor Post</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
	);
	return $messages;
}
add_filter( 'post_updated_messages', 'mgr_cp_updated_messages' );



function mgr_cp_contextual_help( $contextual_help, $screen_id, $screen ) {
	if ( 'contributorpost' == $screen->id ) {

		$contextual_help = '<h2>'. __('Contributors Posts', 'mgr_cp') .'</h2>
		<p>'. __( 'Contributors Posts show the details of the posts of the contributors that we show on the blog. You can see a list of them on this page in reverse chronological order - the latest one we added is first. ', 'mgr_cp') .'</p>
		<p>'. __( 'You can view/edit the details of each Contributor Post by clicking on its name, or you can perform bulk actions using the dropdown menu and selecting multiple items. ', 'mgr_cp') .'</p>';

	} elseif ( 'edit-contributorpost' == $screen->id ) {

		$contextual_help = '<h2>'. __('Editing Contributors Posts', 'mgr_cp') .'</h2>
		<p>'. __('This page allows you to view/modify Contributor Post details. Please make sure to fill out the available boxes with the appropriate details (contributor by, etc) and <strong>not</strong> add these details to the Contributor Post description.', 'mgr_cp') .'</p>';

	}
	return $contextual_help;
}
add_action( 'contextual_help', 'mgr_cp_contextual_help', 10, 3 );


function mgr_cp_taxonomies_contributorpost() {
	$labels = array(
		'name'              => _x( 'Contributors', 'taxonomy general name', 'mgr_cp' ),
		'singular_name'     => _x( 'Contributor', 'taxonomy singular name', 'mgr_cp' ),
		'search_items'      => __( 'Search Contributor', 'mgr_cp' ),
		'all_items'         => __( 'All Contributors', 'mgr_cp' ),
		'parent_item'       => __( 'Parent Contributor', 'mgr_cp' ),
		'parent_item_colon' => __( 'Parent Contributor:', 'mgr_cp' ),
		'edit_item'         => __( 'Edit Contributor', 'mgr_cp' ),
		'update_item'       => __( 'Update Contributor', 'mgr_cp' ),
		'add_new_item'      => __( 'Add New Contributor', 'mgr_cp' ),
		'new_item_name'     => __( 'New Contributor', 'mgr_cp' ),
		'menu_name'         => __( 'Contributors', 'mgr_cp' ),
	);
	$args = array(
		'labels' => $labels,
		'hierarchical' => false,
	);
	register_taxonomy( 'contributor', 'contributorpost', $args );
}
add_action( 'init', 'mgr_cp_taxonomies_contributorpost', 0 );

/* Charge languages files */
function mgr_cp_lang_init() {
  load_plugin_textdomain( 'mgr_cp', false, dirname( plugin_basename( __FILE__ ) ) .'/languages/' );
}
add_action('plugins_loaded', 'mgr_cp_lang_init');


/* Show the List of Contributors and list of posts */
function mgr_cp_contributors_list_with_posts($number_contributors = 5, $contributor_with_description = 1, $show_posts_count = 1, $number_posts = 1, $post_with_description = 0, $except_contributor_id = 0) {

	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

	$is_taxonomy_images = 0;

	if(is_plugin_active('taxonomy-images/taxonomy-images.php')) {
			$is_taxonomy_images = 1;
			global $taxonomy_images_plugin;
	}

	$options = get_option( 'mgr_cp_options' );

		// Customize tags
		$after_contributorBoxSeparator = ( !empty( $options['after_contributorBoxSeparator'] ) ? $options['after_contributorBoxSeparator'] : '<hr/>' );
		$before_contributorBoxDescriptionSeparator = ( !empty( $options['before_contributorBoxDescriptionSeparator'] ) ? $options['before_contributorBoxDescriptionSeparator'] : '<br/>' );

		$before_contributorBox = ( !empty( $options['before_contributorBox'] ) ? $options['before_contributorBox'] : '<div class="contributor_box">' );
		$after_contributorBox = ( !empty( $options['after_contributorBox'] ) ? $options['after_contributorBox'] : '</div>' );
		$before_contributorBoxImage = ( !empty( $options['before_contributorBoxImage'] ) ? $options['before_contributorBoxImage'] : '<div class="contributor_box_image">' );
		$after_contributorBoxImage = ( !empty( $options['after_contributorBoxImage'] ) ? $options['after_contributorBoxImage'] : '</div>' );
		$before_contributorBoxTitle = ( !empty( $options['before_contributorBoxTitle'] ) ? $options['before_contributorBoxTitle'] : '<span class="contributor_box_title">' );
		$after_contributorBoxTitle = ( !empty( $options['after_contributorBoxTitle'] ) ? $options['after_contributorBoxTitle'] : '</span>' );
		$before_contributorBoxPostCount = ( !empty( $options['before_contributorBoxPostCount'] ) ? $options['before_contributorBoxPostCount'] : '<span class="contributor_box_postcount">(<strong>' );
		$after_contributorBoxPostCount = ( !empty( $options['after_contributorBoxPostCount'] ) ? $options['after_contributorBoxPostCount'] : '</strong>)</span>' );
		$before_contributorBoxDescription = ( !empty( $options['before_contributorBoxDescription'] ) ? $options['before_contributorBoxDescription'] : '<div class="contributor_box_desc">' );
		$after_contributorBoxDescription = ( !empty( $options['after_contributorBoxDescription'] ) ? $options['after_contributorBoxDescription'] : '</div>' );
		$before_contributorBoxDescriptionVoid = ( !empty( $options['before_contributorBoxDescriptionVoid'] ) ? $options['before_contributorBoxDescriptionVoid'] : '<div class="contributor_box_desc_void">' );
		$after_contributorBoxDescriptionVoid = ( !empty( $options['after_contributorBoxDescriptionVoid'] ) ? $options['after_contributorBoxDescriptionVoid'] : '</div>' );

		$before_contributorBoxPosts = ( !empty( $options['before_contributorBoxPosts'] ) ? $options['before_contributorBoxPosts'] : '<div class="contributor_posts">' );
		$after_contributorBoxPosts = ( !empty( $options['after_contributorBoxPosts'] ) ? $options['after_contributorBoxPosts'] : '</div>' );
		$before_contributorBoxPostContent = ( !empty( $options['before_contributorBoxPostContent'] ) ? $options['before_contributorBoxPostContent'] : '<div class="contributor_post_content">' );
		$after_contributorBoxPostContent = ( !empty( $options['after_contributorBoxPostContent'] ) ? $options['after_contributorBoxPostContent'] : '</div>' );
		$before_contributorBoxPostTitle = ( !empty( $options['before_contributorBoxPostTitle'] ) ? $options['before_contributorBoxPostTitle'] : '<h3 class="contributor_post_title"><strong>' );
		$after_contributorBoxPostTitle = ( !empty( $options['after_contributorBoxPostTitle'] ) ? $options['after_contributorBoxPostTitle'] : '</strong></h3><br/>' );
		$before_contributorBoxPostDescription = ( !empty( $options['before_contributorBoxPostDescription'] ) ? $options['before_contributorBoxPostDescription'] : '<p class="contributor_post_text">' );
		$after_contributorBoxPostDescription = ( !empty( $options['after_contributorBoxPostDescription'] ) ? $options['after_contributorBoxPostDescription'] : '</p>' );
		$before_contributorBoxPostDescriptionVoid = ( !empty( $options['before_contributorBoxPostDescriptionVoid'] ) ? $options['before_contributorBoxPostDescriptionVoid'] : '<p class="contributor_post_text_void">' );
		$after_contributorBoxPostDescriptionVoid = ( !empty( $options['after_contributorBoxPostDescriptionVoid'] ) ? $options['after_contributorBoxPostDescriptionVoid'] : '</p>' );


	if( !isset($number_posts) || !is_numeric($number_posts) ) $number_posts = 1;
	if( !isset($number_contributors) || !is_numeric($number_contributors) ) $number_contributors = 5;
	if( !isset($contributor_with_description) || !is_numeric($contributor_with_description) ) $contributor_with_description = 1;
	if( !isset($show_posts_count) || !is_numeric($show_posts_count) ) $show_posts_count = 1;
	if(!is_numeric($post_with_description)) {
		if($post_with_description == "long") {
			$post_with_description = 2;
		} elseif($post_with_description == "short") {
			$post_with_description = 1;
		} elseif ($post_with_description == "no") {
			$post_with_description = 0;
		}
	} else {
		if( !isset($post_with_description) || !is_numeric($post_with_description) ) $post_with_description = 0;
	}

	$post_type = 'contributorpost';
	$taxonomy = 'contributor';
	$content_list = '';

	/*/ Get all the taxonomies for this post type
	$taxonomies = get_object_taxonomies( (object) array( 'post_type' => $post_type ) );

	foreach( $taxonomies as $taxonomy ) : */

		// split the contributor id or slug
		if ( strpos( $except_contributor_id, ',' ) === FALSE ) {
			$except_terms[] = mgr_cp_get_termId_by_id_or_slug($except_contributor_id, $taxonomy);
		} else {
			$arrTerms = explode(",", $except_contributor_id);
			if( is_array($arrTerms) ) {
				foreach( $arrTerms as $id )
					$except_terms[] = mgr_cp_get_termId_by_id_or_slug($id, $taxonomy);
			} else // if split is false, set term id to 0
				$except_terms = null;
		}

		if($except_terms === null) {
			$getTermArgs = array(
				'orderby' => 'count',
				'number' => $number_contributors,
				'order'   => 'DESC'
			);
		} else {
			$getTermArgs = array(
				'orderby' => 'count',
				'exclude' => $except_terms,
				'number' => $number_contributors,
				'order'   => 'DESC'
			);
		}
		$terms = get_terms( $taxonomy, $getTermArgs );

		$content_list .= $after_contributorBoxSeparator. " ";
		$num = 1;
		foreach( $terms as $term ) :
				//if($num > $number_contributors) break;
				$posts = new WP_Query( "taxonomy=$taxonomy&term=$term->slug" );
				$link = get_bloginfo( 'url' ) . '/'. $taxonomy .'/' . $term->slug . '/';

				$content_list .= $before_contributorBox. ' ';
				if($is_taxonomy_images) {
					$img = $taxonomy_images_plugin->get_image_html( 'detail', $term->term_taxonomy_id );
					if( !empty( $img ) ) {
						$content_list .= $before_contributorBoxImage. ' ';
						$content_list .= '<a href="' . $link . '">' . $img . '</a>';
						$content_list .= $after_contributorBoxImage. ' ';
					}
				}
				$content_list .= $before_contributorBoxTitle .'<a href="'. $link .'">'. $term->name .'</a>'. $after_contributorBoxTitle;
				if($show_posts_count) {
					$content_list .= ' '.$before_contributorBoxPostCount. $posts->post_count . $after_contributorBoxPostCount.'';
				}
				$content_list .= $before_contributorBoxDescriptionSeparator. ' ';
				if($contributor_with_description) {
					$content_list .= ''. $before_contributorBoxDescription . $term->description .$after_contributorBoxDescription.' ';
				} else {
					$content_list .= ''. $before_contributorBoxDescription .$after_contributorBoxDescription.' ';
				}

				$content_list .= $before_contributorBoxPosts.' ';


			$numPosts = 1;
			while ( $posts->have_posts() && $numPosts <= $number_posts ) {
				$posts->the_post();
				$content_list .= $before_contributorBoxPostContent.' ';
				$content_list .= $before_contributorBoxPostTitle .'<a href="'. get_permalink() .'">'. get_the_title() .'</a>'.$after_contributorBoxPostTitle;

				switch($post_with_description) {
					case "2":
						$content_list .= ''.$before_contributorBoxPostDescription. mgr_cp_get_the_content_with_formatting() .$after_contributorBoxPostDescription.' ';
						break;
					case "1":
						$content_list .= ''.$before_contributorBoxPostDescription. get_the_excerpt() .$after_contributorBoxPostDescription.' ';
						break;
					default:
						$content_list .= ''.$before_contributorBoxPostDescriptionVoid.' '.$after_contributorBoxPostDescriptionVoid.' ';
				}
				$content_list .= $after_contributorBoxPostContent.' '; // contributor_post_content
				$numPosts++;
			}
			$content_list .= $after_contributorBoxPosts	.' '; // contributor_posts

			$content_list .= $after_contributorBox .' '; // contributor_box

			$num++;
	/*	} */
		endforeach;		// End for terms
	/* endforeach; */ // End for taxonomies
	wp_reset_postdata();

	return $content_list;
}

/* Show the Contributors Info and list of posts */
function mgr_cp_contributors_info_with_posts($contributor_id = 0, $contributor_with_description = 0, $show_posts_count = 0, $number_posts = 0, $post_with_description = 0) {

	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

	$is_taxonomy_images = 0;

	if(is_plugin_active('taxonomy-images/taxonomy-images.php')) {
			$is_taxonomy_images = 1;
			global $taxonomy_images_plugin;
	}

	$options = get_option( 'mgr_cp_options' );

		// Customize tags
		$after_contributorBoxSeparator = ( !empty( $options['after_contributorBoxSeparator'] ) ? $options['after_contributorBoxSeparator'] : '<hr/>' );
		$before_contributorBoxDescriptionSeparator = ( !empty( $options['before_contributorBoxDescriptionSeparator'] ) ? $options['before_contributorBoxDescriptionSeparator'] : '<br/>' );

		$before_contributorBox = ( !empty( $options['before_contributorBox'] ) ? $options['before_contributorBox'] : '<div class="contributor_box">' );
		$after_contributorBox = ( !empty( $options['after_contributorBox'] ) ? $options['after_contributorBox'] : '</div>' );
		$before_contributorBoxImage = ( !empty( $options['before_contributorBoxImage'] ) ? $options['before_contributorBoxImage'] : '<div class="contributor_box_image">' );
		$after_contributorBoxImage = ( !empty( $options['after_contributorBoxImage'] ) ? $options['after_contributorBoxImage'] : '</div>' );
		$before_contributorBoxTitle = ( !empty( $options['before_contributorBoxTitle'] ) ? $options['before_contributorBoxTitle'] : '<span class="contributor_box_title">' );
		$after_contributorBoxTitle = ( !empty( $options['after_contributorBoxTitle'] ) ? $options['after_contributorBoxTitle'] : '</span>' );
		$before_contributorBoxPostCount = ( !empty( $options['before_contributorBoxPostCount'] ) ? $options['before_contributorBoxPostCount'] : '<span class="contributor_box_postcount">(<strong>' );
		$after_contributorBoxPostCount = ( !empty( $options['after_contributorBoxPostCount'] ) ? $options['after_contributorBoxPostCount'] : '</strong>)</span>' );
		$before_contributorBoxDescription = ( !empty( $options['before_contributorBoxDescription'] ) ? $options['before_contributorBoxDescription'] : '<div class="contributor_box_desc">' );
		$after_contributorBoxDescription = ( !empty( $options['after_contributorBoxDescription'] ) ? $options['after_contributorBoxDescription'] : '</div>' );
		$before_contributorBoxDescriptionVoid = ( !empty( $options['before_contributorBoxDescriptionVoid'] ) ? $options['before_contributorBoxDescriptionVoid'] : '<div class="contributor_box_desc_void">' );
		$after_contributorBoxDescriptionVoid = ( !empty( $options['after_contributorBoxDescriptionVoid'] ) ? $options['after_contributorBoxDescriptionVoid'] : '</div>' );

		$before_contributorBoxPosts = ( !empty( $options['before_contributorBoxPosts'] ) ? $options['before_contributorBoxPosts'] : '<div class="contributor_posts">' );
		$after_contributorBoxPosts = ( !empty( $options['after_contributorBoxPosts'] ) ? $options['after_contributorBoxPosts'] : '</div>' );
		$before_contributorBoxPostContent = ( !empty( $options['before_contributorBoxPostContent'] ) ? $options['before_contributorBoxPostContent'] : '<div class="contributor_post_content">' );
		$after_contributorBoxPostContent = ( !empty( $options['after_contributorBoxPostContent'] ) ? $options['after_contributorBoxPostContent'] : '</div>' );
		$before_contributorBoxPostTitle = ( !empty( $options['before_contributorBoxPostTitle'] ) ? $options['before_contributorBoxPostTitle'] : '<h3 class="contributor_post_title"><strong>' );
		$after_contributorBoxPostTitle = ( !empty( $options['after_contributorBoxPostTitle'] ) ? $options['after_contributorBoxPostTitle'] : '</strong></h3><br/>' );
		$before_contributorBoxPostDescription = ( !empty( $options['before_contributorBoxPostDescription'] ) ? $options['before_contributorBoxPostDescription'] : '<p class="contributor_post_text">' );
		$after_contributorBoxPostDescription = ( !empty( $options['after_contributorBoxPostDescription'] ) ? $options['after_contributorBoxPostDescription'] : '</p>' );
		$before_contributorBoxPostDescriptionVoid = ( !empty( $options['before_contributorBoxPostDescriptionVoid'] ) ? $options['before_contributorBoxPostDescriptionVoid'] : '<p class="contributor_post_text_void">' );
		$after_contributorBoxPostDescriptionVoid = ( !empty( $options['after_contributorBoxPostDescriptionVoid'] ) ? $options['after_contributorBoxPostDescriptionVoid'] : '</p>' );


	//if( !isset($contributorId) || !is_numeric($contributorId) ) $contributorId = 0;
	if( !isset($contributor_with_description) || !is_numeric($contributor_with_description) ) $contributor_with_description = 0;
	if( !isset($show_posts_count) || !is_numeric($show_posts_count) ) $show_posts_count = 0;
	if( !isset($number_posts) || !is_numeric($number_posts) ) $number_posts = 0;

	if(!is_numeric($post_with_description)) {
		if($post_with_description == "long") {
			$post_with_description = 2;
		} elseif($post_with_description == "short") {
			$post_with_description = 1;
		} elseif ($post_with_description == "no") {
			$post_with_description = 0;
		}
	} else {
		if( !isset($post_with_description) || !is_numeric($post_with_description) ) $post_with_description = 0;
	}

	$term = null;
	$terms = array();
	$post_type = 'contributorpost';
	$taxonomy = 'contributor';
	$content_list = '';

	/*/ Get all the taxonomies for this post type
	$taxonomies = get_object_taxonomies( (object) array( 'post_type' => $post_type ) );

	foreach( $taxonomies as $taxonomy ) : */

		/*/ split the contributor id or slug
		if ( strpos( $contributor_id, ',' ) === FALSE ) {
			$terms[] = mgr_cp_get_term_by_id_or_slug($contributor_id, $taxonomy);
		} else {
			$arrTerms = explode(",", $contributor_id);
			if( is_array($arrTerms) ) {
				foreach( $arrTerms as $id )
					$terms[] = mgr_cp_get_term_by_id_or_slug($id, $taxonomy);
			} else // if split is false, set term id to 0
				$terms[0] = 0;
		} */

		// split the contributor id or slug
		if ( strpos( $contributor_id, ',' ) === FALSE ) {
			$include_terms[] = mgr_cp_get_termId_by_id_or_slug($contributor_id, $taxonomy);
		} else {
			$arrTerms = explode(",", $contributor_id);
			if( is_array($arrTerms) ) {
				foreach( $arrTerms as $id )
					$include_terms[] = mgr_cp_get_termId_by_id_or_slug($id, $taxonomy);
			} else // if split is false, set term id to 0
				$include_terms = null;
		}

		if($include_terms !== null) {
			$getTermArgs = array(
				'orderby' => 'count',
				'include' => $include_terms,
				'number' => $number_contributors,
				'order'   => 'DESC'
			);
		} else {
			$getTermArgs = null;
		}
		$terms = get_terms( $taxonomy, $getTermArgs );

		$content_list .= $after_contributorBoxSeparator. " ";

		foreach( $terms as $term ) :
			$posts = new WP_Query( "taxonomy=$taxonomy&term=$term->slug" );
			$link = get_bloginfo( 'url' ) . '/'. $taxonomy .'/' . $term->slug . '/';

			$content_list .= $before_contributorBox. ' ';
			if($is_taxonomy_images) {
				$img = $taxonomy_images_plugin->get_image_html( 'detail', $term->term_taxonomy_id );
				if( !empty( $img ) ) {
					$content_list .= ''.$before_contributorBoxImage;
					$content_list .= '<a href="' . $link . '">' . $img . '</a>';
					$content_list .= $after_contributorBoxImage .' '; // contributor_box_image
				}
			}
			$content_list .= $before_contributorBoxTitle .'<a href="'. $link .'">'. $term->name .'</a>' .$after_contributorBoxTitle .' ';
			if($show_posts_count) {
				$content_list .= ' '.$before_contributorBoxPostCount. $posts->post_count .$after_contributorBoxPostCount.' ';
			}
			$content_list .= $before_contributorBoxDescriptionSeparator .' ';
			if($contributor_with_description) {
				$content_list .= ''.$before_contributorBoxDescription	. $term->description .$after_contributorBoxDescription.' ';
			} else {
				$content_list .= ' '.$before_contributorBoxDescription .' '. $after_contributorBoxDescriptionVoid .' ';
			}

			$content_list .= $before_contributorBoxPosts .' ';

			$numPosts = 1;
			while ( $posts->have_posts() && $numPosts <= $number_posts ) {
				$posts->the_post();
				$content_list .= $before_contributorBoxPostContent. ' ';
				$content_list .= $before_contributorBoxPostTitle. '<a href="'. get_permalink() .'">'. get_the_title() .'</a>'.$after_contributorBoxPostTitle.' ';

				switch($post_with_description) {
					case "2":
						$content_list .= $before_contributorBoxPostDescription.''. mgr_cp_get_the_content_with_formatting() .$after_contributorBoxPostDescription	.' ';
						break;
					case "1":
						$content_list .= $before_contributorBoxPostDescription.''.  get_the_excerpt() .$after_contributorBoxPostDescription	.' ';
						break;
					default:
						$content_list .= $before_contributorBoxPostDescriptionVoid .' '. $after_contributorBoxPostDescriptionVoid .' ';
				}
				$content_list .= $after_contributorBoxPostContent .' '; // contributor_post_content
				$numPosts++;
			}
			$content_list .= $after_contributorBoxPosts. ' '; // contributor_posts

			$content_list .= $after_contributorBox	.' '; // contributor_box

		endforeach;		// End for terms
	/* endforeach; */ // End for taxonomies
	wp_reset_postdata();

	return $content_list;
}

function mgr_cp_rand_contributors_info_with_posts($contributor_with_description = 0, $show_posts_count = 0, $number_posts = 0, $post_with_description = 0, $except_contributor_id = 0 ) {

		$taxonomy = "contributor";
		$contributor_id = 0;
		$is_except = true;

		/*/ split the contributor id or slug
		if ( strpos( $except_contributor_id, ',' ) === FALSE ) {
			$contributors[] = $except_contributor_id;
		} else {
			$arrContributors = explode(",", $except_contributor_id);
			if( is_array($arrContributors) ) {
				foreach( $arrContributors as $id )
					$contributors[] = $id;
			} else // if split is false, set term id to 0
				$contributors[0] = 0;
		}

		// check to avoid an infinite loop
		$terms = get_terms( $taxonomy );
		if( count($terms) > count($contributors) ) {

			while($is_except) {
				$contributor = mgr_cp_get_rand_term_id($taxonomy);
				if( !in_array($contributor->term_id, $contributors) && !in_array($contributor->slug, $contributors) ) {
					$is_except = false;
				}
			}
			$contributor_id = $contributor->term_id;
		} */

		// split the contributor id or slug
		if ( strpos( $except_contributor_id, ',' ) === FALSE ) {
			$except_terms[] = mgr_cp_get_termId_by_id_or_slug($except_contributor_id, $taxonomy);
		} else {
			$arrTerms = explode(",", $except_contributor_id);
			if( is_array($arrTerms) ) {
				foreach( $arrTerms as $id )
					$except_terms[] = mgr_cp_get_termId_by_id_or_slug($id, $taxonomy);
			} else // if split is false, set term id to 0
				$except_terms = null;
		}

		if($except_terms === null) {
			$getTermArgs = array(
				'orderby' => 'count',
				'order'   => 'DESC'
			);
		} else {
			$getTermArgs = array(
				'orderby' => 'count',
				'exclude' => $except_terms,
				'order'   => 'DESC'
			);
		}
		//$terms = get_terms( $taxonomy, $getTermArgs );
		$contributor = mgr_cp_get_rand_term_id($taxonomy, $getTermArgs);
		$contributor_id = $contributor->term_id;

//$debug =  "[debug] contributor_id: ". $contributor_id ." // contributor_with_description: ". $contributor_with_description ." // ";
//$debug .= "show_posts_count: ". $show_posts_count ." // number_posts: ". $number_posts ." // post_with_description: ". $post_with_description ." <hr>";
		return mgr_cp_contributors_info_with_posts($contributor_id, $contributor_with_description, $show_posts_count, $number_posts, $post_with_description);
}

function mgr_cp_get_rand_term_id($taxonomy, $args = null) {
		if($args === null)
			$terms = get_terms( $taxonomy );
		else
			$terms = get_terms( $taxonomy, $args );
		if(count($terms)>1) {
			$random = rand(0,count($terms)-1); //get a random number from 0 to number of elements in $terms array
			$contributor = $terms[$random];
		} else {
			$contributor = $terms[0];
		}
		return $contributor;
}

/**
 * Get Term Id from a Term Id or Slug
 */
function mgr_cp_get_termId_by_id_or_slug($contributor_id = 0, $taxonomy) {
		if( $contributor_id != 0 && is_numeric($contributor_id) ) {
			// Contributor Id
			//$term = get_term( $contributor_id, $taxonomy );
			$termId = $contributor_id;
		} elseif ( !is_numeric($contributor_id) ) {
			// Contributor Slug
			$term = get_term_by('slug', $contributor_id, $taxonomy );
			$termId = $term->term_id;
			// If term is null yet, I get default Term
			if ( is_null($term) ) {
				$termId = 0;
			}
		}
		return $termId;
}

/**
 * Get Term from a Term Id or Slug
 */
function mgr_cp_get_term_by_id_or_slug($contributor_id = 0, $taxonomy) {
		if( $contributor_id != 0 && is_numeric($contributor_id) ) {
			// Contributor Id
			//$term = get_term( $contributor_id, $taxonomy );
			$term = get_term_by('id', $contributor_id, $taxonomy );
		} elseif ( !is_numeric($contributor_id) ) {
			// Contributor Slug
			$term = get_term_by('slug', $contributor_id, $taxonomy );
		}
		// If term is null yet, I get default Term
		if ( is_null($term) ) {
			$terms = get_terms( $taxonomy );
			$term = $terms[0];
		}
		return $term;
}

/**
 * Get Args for filter Term (It does not used yet)
 */
function mgr_cp_get_contributor_queryarg($contributor_id, $taxonomy, $bExcept) {
	$operator = ($bExcept) ? 'NOT IN' : 'IN';
	$id_or_slug = ( $contributor_id != 0 && is_numeric($contributor_id) ) ? 'id' : 'slug';
	$contributor = array(
			'taxonomy'  => $taxonomy,
			'field'     => $id_or_slug,
			'terms'     => $contributor_id,
			'operator'  => $operator,
	);
	return $contributor;
}
function mgr_cp_get_contributor_queryargs($contributor_id, $taxonomy, $bExcept) {
	if ( strpos( $contributor_id, ',' ) === FALSE ) {
		$args[] =mgr_cp_get_contributor_queryarg($contributor_id, $taxonomy, $bExcept);
		return $args;
	} else {
		$arrTerms = explode(",", $contributor_id);
		if( is_array($arrTerms) ) {
			$args['relation'] = 'AND';
			foreach( $arrTerms as $id )
				$args[] = mgr_cp_get_contributor_queryarg($id, $taxonomy, $bExcept);
		} else // if split is false, set term id to 0
			$args[0] = 0;
		return $args;
	}
}

// SHORTCODES
add_shortcode('contributorsList', 'mgr_cp_contributorsListWithPosts');

function mgr_cp_contributorsListWithPosts($atts) {
		extract(shortcode_atts(array(
			"number_contributors" => '5',
			"contributor_with_description" => '0',
			"show_posts_count" => '0',
			"number_posts" => '1',
			"post_with_description" => '0',
			"except_contributor_id" => '0'
			), $atts));
//$debug =  "[debug] number_contributors: ". $number_contributors ." // contributor_with_description: ". $contributor_with_description ." // ";
//$debug .= "show_posts_count: ". $show_posts_count ." // number_posts: ". $number_posts ." // post_with_description: ". $post_with_description ." <hr>";
		return mgr_cp_contributors_list_with_posts( $number_contributors,$contributor_with_description, $show_posts_count, $number_posts, $post_with_description, $except_contributor_id );
}

// SHORTCODES
add_shortcode('contributorsInfo', 'mgr_cp_contributorsInfoWithPosts');

function mgr_cp_contributorsInfoWithPosts($atts) {
		extract(shortcode_atts(array(
			"contributor_id" => '0',
			"contributor_with_description" => '1',
			"show_posts_count" => '1',
			"number_posts" => '0',
			"post_with_description" => '0'
			), $atts));
//$debug =  "[debug] contributor_id: ". $contributor_id ." // contributor_with_description: ". $contributor_with_description ." // ";
//$debug .= "show_posts_count: ". $show_posts_count ." // number_posts: ". $number_posts ." // post_with_description: ". $post_with_description ." <hr>";
		return mgr_cp_contributors_info_with_posts($contributor_id, $contributor_with_description, $show_posts_count, $number_posts, $post_with_description);
}

// SHORTCODES
add_shortcode('randContributorsInfo', 'mgr_cp_randContributorsInfoWithPosts');

function mgr_cp_randContributorsInfoWithPosts($atts) {
		extract(shortcode_atts(array(
			"contributor_with_description" => '1',
			"show_posts_count" => '1',
			"number_posts" => '0',
			"post_with_description" => '0',
			"except_contributor_id" => '0'
			), $atts));

			return mgr_cp_rand_contributors_info_with_posts( $contributor_with_description, $show_posts_count, $number_posts, $post_with_description, $except_contributor_id );
}

/* Create Widget for show list of Authors */
class mgr_cp_ContributorsListWidget extends WP_Widget {

	function mgr_cp_ContributorsListWidget() {
			parent::__construct( false, 'Contributors List' );
	}

	function widget( $args, $instance ) {

			extract($args);
			$title 		= apply_filters( 'widget_title', $instance['title'] );
			$number_posts 	= isset( $instance['number_posts'] ) ? absint( $instance['number_posts'] ) : 1;
			$number_contributors 	= isset( $instance['number_contributors'] ) ? absint( $instance['number_contributors'] ) : 5;
			$contributor_with_description 	= isset( $instance['contributor_with_description'] ) ? absint( $instance['contributor_with_description'] ) : 1;
			$show_posts_count = isset( $instance['show_posts_count'] ) ? absint( $instance['show_posts_count'] ) : 0;
			$post_with_description 	= isset( $instance['post_with_description'] ) ? absint( $instance['post_with_description'] ) : 0;
			$except_contributor_id 	= isset( $instance['except_contributor_id'] ) ? ( $instance['except_contributor_id'] ) : 0;

			$before_widget = ( !empty( $before_widget ) ? $before_widget : '<div class="ContributorsListWidget">' );
			$after_widget = ( !empty( $after_widget ) ? $after_widget : '</div>' );
			$before_title = ( !empty( $before_title ) ? $before_title : '<h2 class="ContributorsListTitle">' );
			$after_title = ( !empty( $after_title ) ? $after_title : '</h2>' );

			print $before_widget;
			if(!empty($instance['title']) && ($instance['title'] != ''))
				print $before_title.$instance['title'].$after_title;

			print mgr_cp_contributors_list_with_posts( $number_contributors,$contributor_with_description, $show_posts_count, $number_posts, $post_with_description, $except_contributor_id );

			print $after_widget;
	}

	function update($new_instance, $old_instance) {
			$instance 				= $old_instance;
			$instance['title'] 		= isset( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['number_posts'] 	= isset( $new_instance['number_posts'] ) ? strip_tags( $new_instance['number_posts'] ) : 1;
			$instance['number_contributors'] 	= isset( $new_instance['number_contributors'] ) ? strip_tags( $new_instance['number_contributors'] ) : 5;
			$instance['contributor_with_description'] 	= isset( $new_instance['contributor_with_description'] ) ? strip_tags( $new_instance['contributor_with_description'] ) : 0;
			$instance['show_posts_count'] 	= isset( $new_instance['show_posts_count'] ) ? strip_tags( $new_instance['show_posts_count'] ) : 0;
			$instance['post_with_description'] 	= isset( $new_instance['post_with_description'] ) ? strip_tags( $new_instance['post_with_description'] ) : 0;
			$instance['except_contributor_id'] 	= isset( $new_instance['except_contributor_id'] ) ? strip_tags( $new_instance['except_contributor_id'] ) : 0;
			return $instance;
	}

	function form( $instance ) {
			$title 			= isset( $instance['title'] )  ? esc_attr( $instance['title'] ) : '';
			$number_posts			= isset( $instance['number_posts'] ) ? absint( $instance['number_posts'] )  : 1;
			$number_contributors			= isset( $instance['number_contributors'] ) ? absint( $instance['number_contributors'] )  : 1;
			$contributor_with_description			= isset( $instance['contributor_with_description'] ) ? absint( $instance['contributor_with_description'] )  : 1;
			$show_posts_count			= isset( $instance['show_posts_count'] ) ? absint( $instance['show_posts_count'] )  : 0;
			$post_with_description			= isset( $instance['post_with_description'] ) ? absint( $instance['post_with_description'] )  : 0;
			$except_contributor_id			= isset( $instance['except_contributor_id'] ) ? ( $instance['except_contributor_id'] )  : 0;
//echo "[debug] contributor_with_description: ". $contributor_with_description ." // number_posts: ". $number_posts ."<br>";
//echo " show_posts_count: ". $show_posts_count ." // post_with_description: ". $post_with_description ."<hr>";
			?>
			<p><label for="<?php echo $this->get_field_id('title');?>">
			<?php _e('Title', 'mgr_cp') ?>: <input class="widefat" id="<?php echo $this->get_field_id('title');?>" name="<?php echo $this->get_field_name('title');?>" type="text" value="<?php echo $title; ?>" />
			</label></p>
			<p>
				<input id="<?php echo $this->get_field_id('number_contributors'); ?>" class="small-text" name="<?php echo $this->get_field_name('number_contributors'); ?>" type="number_contributors" min="1" step="1" value="<?php echo esc_attr( $number_contributors ); ?>" />
				<label for="<?php echo $this->get_field_id('number_contributors'); ?>"><?php _e('Maximum Contributors to show', 'mgr_cp'); ?></label>
			</p>
			<p>
				<input id="<?php echo $this->get_field_id('show_posts_count'); ?>" name="<?php echo $this->get_field_name('show_posts_count'); ?>" type="checkbox" value="1" <?php checked( '1', $show_posts_count ); ?>/>
        <label for="<?php echo $this->get_field_id('show_posts_count'); ?>"><?php _e('Show posts count', 'mgr_cp'); ?></label>
			</p>
			<p>
				<input id="<?php echo $this->get_field_id('contributor_with_description'); ?>" name="<?php echo $this->get_field_name('contributor_with_description'); ?>" type="checkbox" value="1" <?php checked( '1', $contributor_with_description ); ?>/>
        <label for="<?php echo $this->get_field_id('contributor_with_description'); ?>"><?php _e('Add description of contributor', 'mgr_cp'); ?></label>
			</p>
			<p>
				<input id="<?php echo $this->get_field_id('number_posts'); ?>" class="small-text" name="<?php echo $this->get_field_name('number_posts'); ?>" type="number_posts" min="1" step="1" value="<?php echo esc_attr( $number_posts ); ?>" />
				<label for="<?php echo $this->get_field_id('number_posts'); ?>"><?php _e('Max number of post for each contributor (can be 0)', 'mgr_cp'); ?></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'post_with_description' ); ?> "><?php _e('Choose how to show post description', 'mgr_cp'); ?></label>
				<select id="<?php echo $this->get_field_id( 'post_with_description' ); ?>" name="<?php echo $this->get_field_name( 'post_with_description' ); ?>">
						 <option value="0" <?php selected($post_with_description, '0'); ?>><?php _e('No description', 'mgr_cp'); ?></option>
						 <option value="1" <?php selected($post_with_description, '1'); ?>><?php _e('Short description', 'mgr_cp'); ?></option>
						 <option value="2" <?php selected($post_with_description, '2'); ?>><?php _e('Long description', 'mgr_cp'); ?></option>
				</select>
			</p>
			<p><label for="<?php echo $this->get_field_id('except_contributor_id');?>">
			<?php _e('<strong>Except these</strong> Contributor(s) Id or Slug (divide by comma)', 'mgr_cp'); ?>: <input class="widefat" id="<?php echo $this->get_field_id('except_contributor_id');?>" name="<?php echo $this->get_field_name('except_contributor_id');?>" type="text" value="<?php echo $except_contributor_id; ?>" />
			</label></p>
			<?php
	}
}

function mgr_cp_register_contributorsListWidgets() {
		register_widget( 'mgr_cp_ContributorsListWidget' );
}

add_action( 'widgets_init', 'mgr_cp_register_contributorsListWidgets' );



/* Create Widget for show Author(s) Info */
class mgr_cp_ContributorsInfoWidget extends WP_Widget {

	function mgr_cp_ContributorsInfoWidget() {
			parent::__construct( false, 'Contributor(s) Info' );
	}

	function widget( $args, $instance ) {

			extract($args);
			$title 		= apply_filters( 'widget_title', $instance['title'] );
			$contributor_id = isset( $instance['contributor_id'] ) ? ( $instance['contributor_id'] ) : 0;
			$contributor_with_description 	= isset( $instance['contributor_with_description'] ) ? absint( $instance['contributor_with_description'] ) : 1;
			$number_posts 	= isset( $instance['number_posts'] ) ? absint( $instance['number_posts'] ) : 0;
			$show_posts_count = isset( $instance['show_posts_count'] ) ? absint( $instance['show_posts_count'] ) : 0;
			$post_with_description 	= isset( $instance['post_with_description'] ) ? absint( $instance['post_with_description'] ) : 0;
//echo "[debug] contributor_id: ". $contributor_id ." // contributor_with_description: ". $contributor_with_description ." // number_posts: ". $number_posts ."<br>";
//echo " show_posts_count: ". $show_posts_count ." // post_with_description: ". $post_with_description ."<hr>";

			$before_widget = ( !empty( $before_widget ) ? $before_widget : '<div class="ContributorsInfoWidget">' );
			$after_widget = ( !empty( $after_widget ) ? $after_widget : '</div>' );
			$before_title = ( !empty( $before_title ) ? $before_title : '<h2 class="ContributorsInfoTitle">' );
			$after_title = ( !empty( $after_title ) ? $after_title : '</h2>' );

			print $before_widget;
			if(!empty($instance['title']) && ($instance['title'] != ''))
				print $before_title.$instance['title'].$after_title;
			print mgr_cp_contributors_info_with_posts( $contributor_id, $contributor_with_description, $show_posts_count, $number_posts, $post_with_description );

			print $after_widget;
	}

	function update($new_instance, $old_instance) {
			$instance 				= $old_instance;
			$instance['title'] 		= isset( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['contributor_id'] 	= isset( $new_instance['contributor_id'] ) ? strip_tags( $new_instance['contributor_id'] ) : 0;
			$instance['contributor_with_description'] 	= isset( $new_instance['contributor_with_description'] ) ? strip_tags( $new_instance['contributor_with_description'] ) : 0;
			$instance['number_posts'] 	= isset( $new_instance['number_posts'] ) ? strip_tags( $new_instance['number_posts'] ) : 0;
			$instance['show_posts_count'] 	= isset( $new_instance['show_posts_count'] ) ? strip_tags( $new_instance['show_posts_count'] ) : 0;
			$instance['post_with_description'] 	= isset( $new_instance['post_with_description'] ) ? strip_tags( $new_instance['post_with_description'] ) : 0;
			return $instance;
	}

	function form( $instance ) {
			$title 			= isset( $instance['title'] )  ? esc_attr( $instance['title'] ) : '';
			$contributor_id			= isset( $instance['contributor_id'] ) ? esc_attr( $instance['contributor_id'] )  : 0;
			$contributor_with_description			= isset( $instance['contributor_with_description'] ) ? absint( $instance['contributor_with_description'] )  : 1;
			$show_posts_count			= isset( $instance['show_posts_count'] ) ? absint( $instance['show_posts_count'] )  : 0;
			$number_posts			= isset( $instance['number_posts'] ) ? absint( $instance['number_posts'] )  : 0;
			$post_with_description			= isset( $instance['post_with_description'] ) ? absint( $instance['post_with_description'] )  : 0;
//echo "[debug] contributor_id: ". $contributor_id ." // contributor_with_description: ". $contributor_with_description ." // number_posts: ". $number_posts ."<br>";
//echo " show_posts_count: ". $show_posts_count ." // post_with_description: ". $post_with_description ."<hr>";
			?>
			<p><label for="<?php echo $this->get_field_id('title');?>">
			<?php _e('Title', 'mgr_cp'); ?>: <input class="widefat" id="<?php echo $this->get_field_id('title');?>" name="<?php echo $this->get_field_name('title');?>" type="text" value="<?php echo $title; ?>" />
			</label></p>
			<p><label for="<?php echo $this->get_field_id('contributor_id');?>">
			<?php _e('Contributor(s) Id or Slug (divide by comma)', 'mgr_cp'); ?>: <input class="widefat" id="<?php echo $this->get_field_id('contributor_id');?>" name="<?php echo $this->get_field_name('contributor_id');?>" type="text" value="<?php echo $contributor_id; ?>" />
			</label></p>
			<p>
				<input id="<?php echo $this->get_field_id('contributor_with_description'); ?>" name="<?php echo $this->get_field_name('contributor_with_description'); ?>" type="checkbox" value="1" <?php checked( '1', $contributor_with_description ); ?>/>
        <label for="<?php echo $this->get_field_id('contributor_with_description'); ?>"><?php _e('Add description of contributor', 'mgr_cp'); ?></label>
			</p>
			<p>
				<input id="<?php echo $this->get_field_id('show_posts_count'); ?>" name="<?php echo $this->get_field_name('show_posts_count'); ?>" type="checkbox" value="1" <?php checked( '1', $show_posts_count ); ?>/>
        <label for="<?php echo $this->get_field_id('show_posts_count'); ?>"><?php _e('Show posts count', 'mgr_cp'); ?></label>
			</p>
			<p>
				<input id="<?php echo $this->get_field_id('number_posts'); ?>" class="small-text" name="<?php echo $this->get_field_name('number_posts'); ?>" type="number_posts" min="1" step="1" value="<?php echo esc_attr( $number_posts ); ?>" />
				<label for="<?php echo $this->get_field_id('number_posts'); ?>"><?php _e('Max number of post for each contributor (can be 0)', 'mgr_cp'); ?></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'post_with_description' ); ?> "><?php _e('Choose how to show post description'); ?></label>
				<select id="<?php echo $this->get_field_id( 'post_with_description' ); ?>" name="<?php echo $this->get_field_name( 'post_with_description' ); ?>">
						 <option value="0" <?php selected($post_with_description, '0'); ?>><?php _e('No description', 'mgr_cp'); ?></option>
						 <option value="1" <?php selected($post_with_description, '1'); ?>><?php _e('Short description', 'mgr_cp'); ?></option>
						 <option value="2" <?php selected($post_with_description, '2'); ?>><?php _e('Long description', 'mgr_cp'); ?></option>
				</select>
			</p>
			<?php
	}
}

function mgr_cp_register_contributorsInfoWidgets() {
		register_widget( 'mgr_cp_ContributorsInfoWidget' );
}

add_action( 'widgets_init', 'mgr_cp_register_contributorsInfoWidgets' );

/* Create Widget for show Author(s) Info Random */
class mgr_cp_RandContributorsInfoWidget extends WP_Widget {

	function mgr_cp_RandContributorsInfoWidget() {
			parent::__construct( false, 'Contributor(s) Info [Random]' );
	}

	function widget( $args, $instance ) {

			extract($args);
			$title 		= apply_filters( 'widget_title', $instance['title'] );
			$contributor_with_description 	= isset( $instance['contributor_with_description'] ) ? absint( $instance['contributor_with_description'] ) : 1;
			$number_posts 	= isset( $instance['number_posts'] ) ? absint( $instance['number_posts'] ) : 0;
			$show_posts_count = isset( $instance['show_posts_count'] ) ? absint( $instance['show_posts_count'] ) : 0;
			$post_with_description 	= isset( $instance['post_with_description'] ) ? absint( $instance['post_with_description'] ) : 0;
			$except_contributor_id = isset( $instance['except_contributor_id'] ) ? ( $instance['except_contributor_id'] ) : 0;
//echo "[debug] contributor_id: ". $contributor_id ." // contributor_with_description: ". $contributor_with_description ." // number_posts: ". $number_posts ."<br>";
//echo " show_posts_count: ". $show_posts_count ." // post_with_description: ". $post_with_description ."<hr>";

			$before_widget = ( !empty( $before_widget ) ? $before_widget : '<div class="ContributorsInfoWidget">' );
			$after_widget = ( !empty( $after_widget ) ? $after_widget : '</div>' );
			$before_title = ( !empty( $before_title ) ? $before_title : '<h2 class="ContributorsInfoTitle">' );
			$after_title = ( !empty( $after_title ) ? $after_title : '</h2>' );

			print $before_widget;
			if(!empty($instance['title']) && ($instance['title'] != ''))
				print $before_title.$instance['title'].$after_title;
			print mgr_cp_rand_contributors_info_with_posts( $contributor_with_description, $show_posts_count, $number_posts, $post_with_description, $except_contributor_id );

			print $after_widget;
	}

	function update($new_instance, $old_instance) {
			$instance 				= $old_instance;
			$instance['title'] 		= isset( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['contributor_with_description'] 	= isset( $new_instance['contributor_with_description'] ) ? strip_tags( $new_instance['contributor_with_description'] ) : 0;
			$instance['number_posts'] 	= isset( $new_instance['number_posts'] ) ? strip_tags( $new_instance['number_posts'] ) : 0;
			$instance['show_posts_count'] 	= isset( $new_instance['show_posts_count'] ) ? strip_tags( $new_instance['show_posts_count'] ) : 0;
			$instance['post_with_description'] 	= isset( $new_instance['post_with_description'] ) ? strip_tags( $new_instance['post_with_description'] ) : 0;
			$instance['except_contributor_id'] 	= isset( $new_instance['except_contributor_id'] ) ? strip_tags( $new_instance['except_contributor_id'] ) : 0;
			return $instance;
	}

	function form( $instance ) {
			$title 			= isset( $instance['title'] )  ? esc_attr( $instance['title'] ) : '';
			$contributor_with_description			= isset( $instance['contributor_with_description'] ) ? absint( $instance['contributor_with_description'] )  : 1;
			$show_posts_count			= isset( $instance['show_posts_count'] ) ? absint( $instance['show_posts_count'] )  : 0;
			$number_posts			= isset( $instance['number_posts'] ) ? absint( $instance['number_posts'] )  : 0;
			$post_with_description			= isset( $instance['post_with_description'] ) ? absint( $instance['post_with_description'] )  : 0;
			$except_contributor_id			= isset( $instance['except_contributor_id'] ) ? esc_attr( $instance['except_contributor_id'] )  : 0;
//echo "[debug] contributor_id: ". $contributor_id ." // contributor_with_description: ". $contributor_with_description ." // number_posts: ". $number_posts ."<br>";
//echo " show_posts_count: ". $show_posts_count ." // post_with_description: ". $post_with_description ."<hr>";
			?>
			<p><label for="<?php echo $this->get_field_id('title');?>">
			<?php _e('Title', 'mgr_cp'); ?>: <input class="widefat" id="<?php echo $this->get_field_id('title');?>" name="<?php echo $this->get_field_name('title');?>" type="text" value="<?php echo $title; ?>" />
			</label></p>
			<p>
				<input id="<?php echo $this->get_field_id('contributor_with_description'); ?>" name="<?php echo $this->get_field_name('contributor_with_description'); ?>" type="checkbox" value="1" <?php checked( '1', $contributor_with_description ); ?>/>
        <label for="<?php echo $this->get_field_id('contributor_with_description'); ?>"><?php _e('Add description of contributor', 'mgr_cp'); ?></label>
			</p>
			<p>
				<input id="<?php echo $this->get_field_id('show_posts_count'); ?>" name="<?php echo $this->get_field_name('show_posts_count'); ?>" type="checkbox" value="1" <?php checked( '1', $show_posts_count ); ?>/>
        <label for="<?php echo $this->get_field_id('show_posts_count'); ?>"><?php _e('Show posts count', 'mgr_cp'); ?></label>
			</p>
			<p>
				<input id="<?php echo $this->get_field_id('number_posts'); ?>" class="small-text" name="<?php echo $this->get_field_name('number_posts'); ?>" type="number_posts" min="1" step="1" value="<?php echo esc_attr( $number_posts ); ?>" />
				<label for="<?php echo $this->get_field_id('number_posts'); ?>"><?php _e('Max number of post for each contributor (can be 0)', 'mgr_cp'); ?></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'post_with_description' ); ?> "><?php _e('Choose how to show post description'); ?></label>
				<select id="<?php echo $this->get_field_id( 'post_with_description' ); ?>" name="<?php echo $this->get_field_name( 'post_with_description' ); ?>">
						 <option value="0" <?php selected($post_with_description, '0'); ?>><?php _e('No description', 'mgr_cp'); ?></option>
						 <option value="1" <?php selected($post_with_description, '1'); ?>><?php _e('Short description', 'mgr_cp'); ?></option>
						 <option value="2" <?php selected($post_with_description, '2'); ?>><?php _e('Long description', 'mgr_cp'); ?></option>
				</select>
			</p>
			<p><label for="<?php echo $this->get_field_id('except_contributor_id');?>">
			<?php _e('<strong>Except these</strong> Contributor(s) Id or Slug (divide by comma)', 'mgr_cp'); ?>: <input class="widefat" id="<?php echo $this->get_field_id('except_contributor_id');?>" name="<?php echo $this->get_field_name('except_contributor_id');?>" type="text" value="<?php echo $except_contributor_id; ?>" />
			</label></p>
			<?php
	}
}

function mgr_cp_register_randContributorsInfoWidgets() {
		register_widget( 'mgr_cp_RandContributorsInfoWidget' );
}

add_action( 'widgets_init', 'mgr_cp_register_randContributorsInfoWidgets' );



/* Add template page for Contributors' Posts */
function mgr_cp_include_template_function( $template_path ) {
    if ( get_post_type() == 'contributorpost' ) {
        if ( is_single() ) {
            // checks if the file exists in the theme first,
            // otherwise serve the file from the plugin
            if ( $theme_file = locate_template( array ( 'single-contributorpost.php' ) ) ) {
                $template_path = $theme_file;
            } else {
                $template_path = plugin_dir_path( __FILE__ ) . '/single-contributorpost.php';
            }
        } elseif ( is_archive() ) {
            // checks if the file exists in the theme first,
            // otherwise serve the file from the plugin
            if ( $theme_file = locate_template( array ( 'archive-contributorpost.php' ) ) ) {
                $template_path = $theme_file;
            } else {
                $template_path = plugin_dir_path( __FILE__ ) . '/archive-contributorpost.php';
            }
				}
    }
    return $template_path;
}
add_filter( 'template_include', 'mgr_cp_include_template_function', 1 );


/* Add Stylesheet for Plugin */
function mgr_cp_queue_stylesheet() {
	if ( is_readable( plugin_dir_path( __FILE__ ) . 'custom-style.css' ) ) {
			wp_enqueue_style( 'mgr_cp_stylesheet', plugins_url( 'custom-style.css', __FILE__ ) );  //plugin_dir_url( __FILE__ ) . 'custom-style.css' );
	} else {
			wp_enqueue_style( 'mgr_cp_stylesheet', plugins_url( 'style.css', __FILE__ ) );
	}
}
add_action( 'wp_enqueue_scripts', 'mgr_cp_queue_stylesheet');

function mgr_cp_get_the_content_with_formatting ($more_link_text = '(more...)', $stripteaser = 0, $more_file = '') {
	$content = get_the_content($more_link_text, $stripteaser, $more_file);
	$content = apply_filters('the_content', $content);
	$content = str_replace(']]>', ']]&gt;', $content);
	return $content;
}


register_activation_hook( __FILE__ , 'mgr_cp_set_default_options_array' );

function mgr_cp_set_default_options_array() {
	if( false === get_option( 'mgr_cp_options' ) ) {
		$new_options = array();
		$new_options['after_contributorBoxSeparator'] = '<hr/>';
		$new_options['before_contributorBoxDescriptionSeparator'] = '<br/>';

		$new_options['before_contributorBox'] = '<div class="contributor_box">';
		$new_options['after_contributorBox'] = '</div>';
		$new_options['before_contributorBoxImage'] = '<div class="contributor_box_image">';
		$new_options['after_contributorBoxImage'] = '</div>';
		$new_options['before_contributorBoxTitle'] = '<h2 class="heading contributor_box_title">';
		$new_options['after_contributorBoxTitle'] = '</h2>';
		$new_options['before_contributorBoxPostCount'] = '<span class="contributor_box_postcount">(<strong>';
		$new_options['after_contributorBoxPostCount'] = '</strong>)</span>';
		$new_options['before_contributorBoxDescription'] = '<div class="contributor_box_desc">';
		$new_options['after_contributorBoxDescription'] = '</div>';
		$new_options['before_contributorBoxDescriptionVoid'] = '<div class="contributor_box_desc_voids">';
		$new_options['after_contributorBoxDescriptionVoid'] = '</div>';

		$new_options['before_contributorBoxPosts'] = '<div class="contributor_posts">';
		$new_options['after_contributorBoxPosts'] = '</div>';
		$new_options['before_contributorBoxPostContent'] = '<div class="contributor_post_content">';
		$new_options['after_contributorBoxPostContent'] = '</div>';
		$new_options['before_contributorBoxPostTitle'] = '<h3 class="contributor_post_title"><strong>';
		$new_options['after_contributorBoxPostTitle'] = '</strong></h3>';
		$new_options['before_contributorBoxPostDescription'] = '<p class="contributor_post_text">';
		$new_options['after_contributorBoxPostDescription'] = '</p>';
		$new_options['before_contributorBoxPostDescriptionVoid'] = '<p class="contributor_post_text_void">';
		$new_options['after_contributorBoxPostDescriptionVoid'] = '</p>';

		add_option( 'mgr_cp_options', $new_options );
	}
}

add_action( 'admin_menu', 'mgr_cp_settings_menu' );

function mgr_cp_settings_menu() {
	add_options_page(
		__( 'Contributors Posts Configuration', 'mgr_cp' ),
		__('Contributors Posts Settings', 'mgr_cp'),
		'manage_options',
		'mgr_cp_contributorsposts', 'mgr_cp_config_page' );
}

function mgr_cp_admin_tabs( $current = 'general' ) {
    $tabs = array( 'general' => __('General Settings', 'mgr_cp'), 'support' => __('Support and Donate', 'mgr_cp') );
    echo '<div id="icon-themes" class="icon32"><br></div>';

		?><a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/3.0/">
			<img align="right" src="<?php print(plugins_url('images/wiball_onkeyboard.png', __FILE__)) ?>" width="226" height="186" alt="<?php _e('Wiball on keybord (C) Elisa Ragni 2010 by-nc-nd-3.0', 'mgr_cp');?>" title="<?php _e('Wiball on keybord (C) Elisa Ragni 2010 by-nc-nd-3.0', 'mgr_cp');?>" /></a>
    <h1><?php _e( 'General Settings for Contributors\' Posts', 'mgr_cp' ); ?></h1><?php
		echo '<h2 class="nav-tab-wrapper">';
    foreach( $tabs as $tab => $name ){
        $class = ( $tab == $current ) ? ' nav-tab-active' : '';
        echo "<a class='nav-tab$class' href='?page=mgr_cp_contributorsposts&tab=$tab'>$name</a>";

    }
    echo '</h2>';
}

function mgr_cp_config_page( ) {
	$options = get_option( 'mgr_cp_options' );

	if ( isset ( $_GET['tab'] ) ) mgr_cp_admin_tabs($_GET['tab']); else mgr_cp_admin_tabs('general');

	?>
	<div id="mgr_cp-general" class="wrap">

			<?php
			if ( isset ( $_GET['tab'] ) ) $tab = $_GET['tab'];
			else $tab = 'general'; ?>
		<table>
			<colgroup>
				<col style="width:80%;">
				<col style="width:20%;">
			</colgroup>
			<tr>
				<td>

						<?php
						switch ( $tab ){
							case 'general' : /**** GENERAL SETTINGS ****/
								 ?>
					<form method="post" action="admin-post.php">
						<?php wp_nonce_field( 'mgr_cp' ); ?>
						<input type="hidden" name="action" value="save_mgr_cp_options" />

						<table class="form-table">
							<caption><h3><?php _e( 'Customize HTML tags of the Contributor Box', 'mgr_cp' ); ?></h3></caption>
							<colgroup>
								<col style="width:30%;">
								<col style="width:70%;">
							</colgroup>
							<tr>
								<td align="right"><?php _e( 'HTML Start Separator', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxSeparator"><?php echo ( html_entity_decode($options['after_contributorBoxSeparator'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Description Separator (before)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxDescriptionSeparator"><?php echo ( html_entity_decode($options['before_contributorBoxDescriptionSeparator'] )); ?></textarea></td>
							</tr>

							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box (Opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBox"><?php echo ( html_entity_decode($options['before_contributorBox'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBox"><?php echo ( html_entity_decode($options['after_contributorBox'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Image (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxImage"><?php echo ( html_entity_decode($options['before_contributorBoxImage'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Image (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxImage"><?php echo ( html_entity_decode($options['after_contributorBoxImage'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Title (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxTitle"><?php echo ( html_entity_decode($options['before_contributorBoxTitle'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Title (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxTitle"><?php echo ( html_entity_decode($options['after_contributorBoxTitle'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Count (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxPostCount"><?php echo ( html_entity_decode($options['before_contributorBoxPostCount'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Count (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxPostCount"><?php echo ( html_entity_decode($options['after_contributorBoxPostCount'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Description (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxDescription"><?php echo ( html_entity_decode($options['before_contributorBoxDescription'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Description (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxDescription"><?php echo ( html_entity_decode($options['after_contributorBoxDescription'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Description Empty (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxDescriptionVoid"><?php echo ( html_entity_decode($options['before_contributorBoxDescriptionVoid'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Description Empty (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxDescriptionVoid"><?php echo ( html_entity_decode($options['after_contributorBoxDescriptionVoid'] )); ?></textarea></td>
							</tr>

							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Posts Box (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxPosts"><?php echo ( html_entity_decode($options['before_contributorBoxPosts'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Posts Box (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxPosts"><?php echo ( html_entity_decode($options['after_contributorBoxPosts'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Content (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxPostContent"><?php echo ( html_entity_decode($options['before_contributorBoxPostContent'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Content (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxPostContent"><?php echo ( html_entity_decode($options['after_contributorBoxPostContent'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Title (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxPostTitle"><?php echo ( html_entity_decode($options['before_contributorBoxPostTitle'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Title (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxPostTitle"><?php echo ( html_entity_decode($options['after_contributorBoxPostTitle'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Description (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxPostDescription"><?php echo ( html_entity_decode($options['before_contributorBoxPostDescription'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Description (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxPostDescription"><?php echo ( html_entity_decode($options['after_contributorBoxPostDescription'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Description Empty (opening)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="before_contributorBoxPostDescriptionVoid"><?php echo ( html_entity_decode($options['before_contributorBoxPostDescriptionVoid'] )); ?></textarea></td>
							</tr>
							<tr>
								<td align="right"><?php _e( 'HTML Contributor Box Post Description Empty (closing)', 'mgr_cp' ); ?>:</td>
								<td align="left"><textarea style="width:90%" name="after_contributorBoxPostDescriptionVoid"><?php echo ( html_entity_decode($options['after_contributorBoxPostDescriptionVoid'] )); ?></textarea></td>
							</tr>

							<tr>
								<td colspan="2" align="center"><input type="submit" value="<?php _e( 'Submit', 'mgr_cp' ); ?>" class="button-primary" /></td>
							</tr>
						</table>

					</form>
						<?php
							break;


							case "support": /**** SUPPORT AND DONATE ****/ ?>
						<table class="form-table">
							<caption><h3><?php _e( 'Support and Donate', 'mgr_cp' ); ?></h3></caption>
							<tr>
								<td>
									<p><?php _e('<strong>Contributors\' Posts</strong> is a plugin developed by Simone "Magicianred" Paolucci.', 'mgr_cp') ?></p>
									<p><?php _e('Visit his website to learn about other projects he have realized.', 'mgr_cp'); ?></p>
									<p><a href="http://simone.paolucci.name/projects.php">http://simone.paolucci.name/projects.php</a></p>
									<p><?php _e('You can know more about this plugin, to send suggestions and to give your vote through the website Wordpress.org, where the plugin is distributed.', 'mgr_cp'); ?></p>
									<p><a href="http://wordpress.org/extend/plugins/contributors-posts/">http://wordpress.org/extend/plugins/contributors-posts/</a></p>
								</td>
							</tr>
							<tr>
								<td>
									<p><?php _e('You can also contribute to the development of the project by making a donation to the developer.', 'mgr_cp'); ?></p>
									<table class="donation_methods" style="border:dashed thin black;width:90%;text-align:center;">
										<tr>
											<td>
												<!-- Begin Skrill Donations -->
												<div class="skrill">
													<form action="https://www.moneybookers.com/app/payment.pl" method="post" target="_blank">
														<input type="hidden" name="pay_to_email" value="magicianred@gmail.com" />
														<input type="hidden" name="recipient_description" value="Simone Paolucci" />
														<input type="hidden" name="status_url" value="mailto:magicianred@gmail.com" />
														<input type="hidden" name="return_url" value="http://magicianred.altervista.org/thankyou" />
														<input type="hidden" name="language" value="IT" />
														<input type="text" name="amount" value="5.00" style="width:70px;" /> EUR<br />
														<input type="hidden" name="currency" value="EUR" />
														<input type="hidden" name="detail1_description" value="<?php _e('Donation', 'mgr_cp'); ?>" />
														<input type="hidden" name="detail1_text" value="<?php _e('Donation to the development of Wordpress plugins Contributors Posts', 'mgr_cp'); ?>" />
														<input style="background: url('<?php print(plugins_url('images/skrill_chkout.gif', __FILE__)) ?>') no-repeat top left;width: 110px;height:52px;" type="submit" value="" />
													</form>
												</div>
												<!-- End Skrill Donations -->
											</td>
											<td>
												<!-- Begin PayPal Donations -->
												<div class="paypal">
													<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_blank">
															<div class="paypal-donations">
																<input type="hidden" name="cmd" value="_donations" />
																<input type="hidden" name="business" value="magicianred@gmail.com" />
																<input type="hidden" name="return" value="http://magicianred.altervista.org/thankyou" />
																<input type="hidden" name="item_name" value="<?php _e('Donation to the development of Wordpress plugins Contributors Posts', 'mgr_cp'); ?>" />
																<input type="hidden" name="item_number" value="Simone Paolucci" />
																<input type="text" name="amount" value="5" style="width:80%" /> EUR<br/>
																<input type="hidden" name="rm" value="0" />
																<input type="hidden" name="currency_code" value="EUR" />
																<input type="image" src="https://www.paypal.com/it_IT/IT/i/btn/btn_donateCC_LG.gif" style="width:221px;height:47px;" name="submit" alt="PayPal - The safer, easier way to pay online." />
																<img alt="" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1" />
															</div>
													</form>
												</div>
												<!-- End PayPal Donations -->
											</td>
											<td>
												<div id="flattr">
													<a href="http://flattr.com/thing/1308113/Wordpress-plugin-Contributors-Posts" target="_blank"><img src="http://api.flattr.com/button/flattr-badge-large.png" alt="Flattr this" title="Flattr this" border="0" /></a>
												</div>
											</td>
											<td style="width:50%"></td>
										</tr>
									</table>
								</td>
							</tr>
						</table>

							<?php } ?>
				</td>

				<?php
						$rss_uri = 'http://simone.paolucci.name/wordpress/plugins/contributorsposts/contributorsposts.rss.php';
						$rss_items_num = 10;
				?>
				<td style="vertical-align:top;border-left:dashed thin black;padding-left:10px;">
					<h3><?php _e('Last News about Plugin','mgr_cp');?></h3>
					<?php
						// Get RSS Feed(s)
						include_once( ABSPATH . WPINC . '/feed.php' );
						/* START CODE from: http://www.problogger.net/archives/2010/12/03/everything-you-need-to-import-and-display-rss-feeds-with-wordpress/ */
						if(function_exists( 'fetch_feed' ) ) {
							// fetch feed items
							$rss = fetch_feed( $rss_uri );
							if( !is_wp_error( $rss ) ) : // error check
								$maxitems = $rss->get_item_quantity( $rss_items_num ); // number of items
								$rss_items = $rss->get_items( 0, $maxitems );
							endif;
							// display feed items ?>
							<!--h3><?php echo $rss->get_title(); ?></h3-->
							<dl>
								<?php if( $maxitems == 0 ) echo '<dt>'. _e('Feed not available','mgr_cp') .'.</dt>';
								else foreach( $rss_items as $item ) : ?>
									<dt>
										<a href="<?php echo $item->get_permalink(); ?>"
											title="<?php echo $item->get_date( 'j F Y @ g:i a' ); ?>">
										<?php echo $item->get_title(); ?></a>
									</dt>
									<dd><?php echo $item->get_description(); ?></dd>
								<?php endforeach; ?>
							</dl>
						<?php }
						/* END CODE from: http://www.problogger.net/archives/2010/12/03/everything-you-need-to-import-and-display-rss-feeds-with-wordpress/ */
						else {
							include_once( ABSPATH.WPINC.'/rss.php' );
							wp_rss( $rss_uri , $rss_items_num );
						}
					?>
					<p><a href="<?php echo $rss_uri ?>" target="_blank" title="<?php _e('Read latest news about plugin','mgr_cp') ?>">
						<?php _e('Show RSS Last News about plugin','mgr_cp') ?></a></p>
				</td>
			</tr>
		</table>
			<br><br>
			<table style="border:dashed thin black;width:90%;text-align:center;">
				<caption><h3><?php _e('Credits and Attributions','mgr_cp');?></h3></caption>
				<tr>
					<td>
						'<span xmlns:dct="http://purl.org/dc/terms/" href="http://purl.org/dc/dcmitype/StillImage" property="dct:title" rel="dct:type">Wiball on keyboard</span>'
						<?php print(_e('by', 'mgr_cp')); ?> <a xmlns:cc="http://creativecommons.org/ns#" href="http://simone.paolucci.name/themes/web/images/logo.png" property="cc:attributionName" rel="cc:attributionURL">
							Elisa Ragni</a>
						<?php print(_e('is licensed under a', 'mgr_cp')); ?> <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/3.0/">
							<?php print(_e('Creative Commons Attribution - Non Commercial - Share Alike 3.0 Unported License', 'mgr_cp')); ?></a>.<br/>
							<?php print(_e('Permissions beyond the scope of this license may be available at', 'mgr_cp')); ?>
						<a xmlns:cc="http://creativecommons.org/ns#" href="http://www.facebook.com/pages/Elisa-Ragni/159242230776374" rel="cc:morePermissions">
							Elisa Ragni - <?php print(_e('Facebook Page', 'mgr_cp')); ?></a>.
					</td>
				</tr>
			</table>
	</div>
<?php }

add_action( 'admin_init', 'mgr_cp_admin_init' );

function mgr_cp_admin_init() {
	add_action( 'admin_post_save_mgr_cp_options', 'mgr_cp_save_options' );
}

function mgr_cp_save_options() {
	if( !current_user_can( 'manage_options' ) )
		wp_die( __('Not allowed', 'mgr_cp') );

	check_admin_referer( 'mgr_cp' );

	$options = get_option( 'mgr_cp_options' );
	if ( isset ( $_GET['tab'] ) )
		 $tab = $_GET['tab'];
	else
		 $tab = 'general';

	switch ( $tab ){
		 case 'general' :
				$options['after_contributorBoxSeparator'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxSeparator'])));
				$options['before_contributorBoxDescriptionSeparator'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxDescriptionSeparator'])));

				$options['before_contributorBox'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBox'])));
				$options['after_contributorBox'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBox'])));
				$options['before_contributorBoxImage'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxImage'])));
				$options['after_contributorBoxImage'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxImage'])));
				$options['before_contributorBoxTitle'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxTitle'])));
				$options['after_contributorBoxTitle'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxTitle'])));
				$options['before_contributorBoxPostCount'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxPostCount'])));
				$options['after_contributorBoxPostCount'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxPostCount'])));
				$options['before_contributorBoxDescription'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxDescription'])));
				$options['after_contributorBoxDescription'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxDescription'])));
				$options['before_contributorBoxDescriptionVoid'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxDescriptionVoid'])));
				$options['after_contributorBoxDescriptionVoid'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxDescriptionVoid'])));

				$options['before_contributorBoxPosts'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxPosts'])));
				$options['after_contributorBoxPosts'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxPosts'])));
				$options['before_contributorBoxPostContent'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxPostContent'])));
				$options['after_contributorBoxPostContent'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxPostContent'])));
				$options['before_contributorBoxPostTitle'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxPostTitle'])));
				$options['after_contributorBoxPostTitle'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxPostTitle'])));
				$options['before_contributorBoxPostDescription'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxPostDescription'])));
				$options['after_contributorBoxPostDescription'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxPostDescription'])));
				$options['before_contributorBoxPostDescriptionVoid'] = stripslashes(wp_filter_post_kses(addslashes($_POST['before_contributorBoxPostDescriptionVoid'])));
				$options['after_contributorBoxPostDescriptionVoid'] = stripslashes(wp_filter_post_kses(addslashes($_POST['after_contributorBoxPostDescriptionVoid'])));
		break;

		case 'donate':

		break;
	}
	update_option( 'mgr_cp_options', $options );

	wp_redirect( add_query_arg( array('page' => 'mgr_cp_contributorsposts', 'tab' => $tab),  admin_url( 'options-general.php' ) ) );

	exit;
}
